@@ -1059,7 +1059,7 @@ class carrierType(GeneratedsSuper):
         else:
             eol_ = ''
         for fleet_ in self.fleet:
-            fleet_.export(outfile, level, namespaceprefix_, namespacedef_='', pretty_print=pretty_print)
+            fleet_.export(outfile, level, namespaceprefix_, name_='fleet', namespacedef_='', pretty_print=pretty_print)
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
         if SaveElementTreeNode:
@@ -1200,7 +1200,7 @@ class Car(Vehicle):
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
-        super(Car, self).__init__( **kwargs_)
+        super(globals().get("Car"), self).__init__( **kwargs_)
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
@@ -1281,7 +1281,7 @@ class Plane(Vehicle):
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
-        super(Plane, self).__init__( **kwargs_)
+        super(globals().get("Plane"), self).__init__( **kwargs_)
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
