@@ -1201,7 +1201,7 @@ class dog(animal):
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
-        super(dog, self).__init__( **kwargs_)
+        super(globals().get("dog"), self).__init__( **kwargs_)
         self.name = name
         self.name_nsprefix_ = None
     def factory(*args_, **kwargs_):
