@@ -1409,7 +1409,7 @@ class USAddress(Address):
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
-        super(USAddress, self).__init__(name, street, city,  **kwargs_)
+        super(globals().get("USAddress"), self).__init__(name, street, city,  **kwargs_)
         self.state = state
         self.validate_USState(self.state)
         self.state_nsprefix_ = None
@@ -1549,7 +1549,7 @@ class UKAddress(Address):
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
-        super(UKAddress, self).__init__(name, street, city,  **kwargs_)
+        super(globals().get("UKAddress"), self).__init__(name, street, city,  **kwargs_)
         self.exportCode = _cast(int, exportCode)
         self.exportCode_nsprefix_ = None
         self.postcode = postcode
